/* abstractsortedset.c generated by valac 0.56.17, the Vala compiler
 * generated from abstractsortedset.vala, do not modify */

/* abstractsortedset.vala
 *
 * Copyright (C) 2009-2011  Maciej Piechotka
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Maciej Piechotka <uzytkownik2@gmail.com>
 */

#include "gee.h"
#include <glib-object.h>
#include <glib.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif

enum  {
	GEE_ABSTRACT_SORTED_SET_0_PROPERTY,
	GEE_ABSTRACT_SORTED_SET_G_TYPE,
	GEE_ABSTRACT_SORTED_SET_G_DUP_FUNC,
	GEE_ABSTRACT_SORTED_SET_G_DESTROY_FUNC,
	GEE_ABSTRACT_SORTED_SET_READ_ONLY_VIEW_PROPERTY,
	GEE_ABSTRACT_SORTED_SET_NUM_PROPERTIES
};
static GParamSpec* gee_abstract_sorted_set_properties[GEE_ABSTRACT_SORTED_SET_NUM_PROPERTIES];

#define GEE_TYPE_READ_ONLY_COLLECTION (gee_read_only_collection_get_type ())
#define GEE_READ_ONLY_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GEE_TYPE_READ_ONLY_COLLECTION, GeeReadOnlyCollection))
#define GEE_READ_ONLY_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GEE_TYPE_READ_ONLY_COLLECTION, GeeReadOnlyCollectionClass))
#define GEE_IS_READ_ONLY_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GEE_TYPE_READ_ONLY_COLLECTION))
#define GEE_IS_READ_ONLY_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GEE_TYPE_READ_ONLY_COLLECTION))
#define GEE_READ_ONLY_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GEE_TYPE_READ_ONLY_COLLECTION, GeeReadOnlyCollectionClass))

typedef struct _GeeReadOnlyCollection GeeReadOnlyCollection;
typedef struct _GeeReadOnlyCollectionClass GeeReadOnlyCollectionClass;

#define GEE_TYPE_READ_ONLY_SET (gee_read_only_set_get_type ())
#define GEE_READ_ONLY_SET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GEE_TYPE_READ_ONLY_SET, GeeReadOnlySet))
#define GEE_READ_ONLY_SET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GEE_TYPE_READ_ONLY_SET, GeeReadOnlySetClass))
#define GEE_IS_READ_ONLY_SET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GEE_TYPE_READ_ONLY_SET))
#define GEE_IS_READ_ONLY_SET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GEE_TYPE_READ_ONLY_SET))
#define GEE_READ_ONLY_SET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GEE_TYPE_READ_ONLY_SET, GeeReadOnlySetClass))

typedef struct _GeeReadOnlySet GeeReadOnlySet;
typedef struct _GeeReadOnlySetClass GeeReadOnlySetClass;

#define GEE_TYPE_READ_ONLY_SORTED_SET (gee_read_only_sorted_set_get_type ())
#define GEE_READ_ONLY_SORTED_SET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GEE_TYPE_READ_ONLY_SORTED_SET, GeeReadOnlySortedSet))
#define GEE_READ_ONLY_SORTED_SET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GEE_TYPE_READ_ONLY_SORTED_SET, GeeReadOnlySortedSetClass))
#define GEE_IS_READ_ONLY_SORTED_SET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GEE_TYPE_READ_ONLY_SORTED_SET))
#define GEE_IS_READ_ONLY_SORTED_SET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GEE_TYPE_READ_ONLY_SORTED_SET))
#define GEE_READ_ONLY_SORTED_SET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GEE_TYPE_READ_ONLY_SORTED_SET, GeeReadOnlySortedSetClass))

typedef struct _GeeReadOnlySortedSet GeeReadOnlySortedSet;
typedef struct _GeeReadOnlySortedSetClass GeeReadOnlySortedSetClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

struct _GeeAbstractSortedSetPrivate {
	GType g_type;
	GBoxedCopyFunc g_dup_func;
	GDestroyNotify g_destroy_func;
	GWeakRef _read_only_view;
};

static gint GeeAbstractSortedSet_private_offset;
static gpointer gee_abstract_sorted_set_parent_class = NULL;
static GeeSortedSetIface * gee_abstract_sorted_set_gee_sorted_set_parent_iface = NULL;

 G_GNUC_INTERNAL void gee_abstract_sorted_set_reserved0 (GeeAbstractSortedSet* self);
 G_GNUC_INTERNAL void gee_abstract_sorted_set_reserved1 (GeeAbstractSortedSet* self);
 G_GNUC_INTERNAL void gee_abstract_sorted_set_reserved2 (GeeAbstractSortedSet* self);
 G_GNUC_INTERNAL void gee_abstract_sorted_set_reserved3 (GeeAbstractSortedSet* self);
 G_GNUC_INTERNAL void gee_abstract_sorted_set_reserved4 (GeeAbstractSortedSet* self);
 G_GNUC_INTERNAL void gee_abstract_sorted_set_reserved5 (GeeAbstractSortedSet* self);
 G_GNUC_INTERNAL void gee_abstract_sorted_set_reserved6 (GeeAbstractSortedSet* self);
 G_GNUC_INTERNAL void gee_abstract_sorted_set_reserved7 (GeeAbstractSortedSet* self);
 G_GNUC_INTERNAL void gee_abstract_sorted_set_reserved8 (GeeAbstractSortedSet* self);
 G_GNUC_INTERNAL void gee_abstract_sorted_set_reserved9 (GeeAbstractSortedSet* self);
static gpointer gee_abstract_sorted_set_real_first (GeeAbstractSortedSet* self);
static gpointer gee_abstract_sorted_set_real_last (GeeAbstractSortedSet* self);
static GeeIterator* gee_abstract_sorted_set_real_iterator_at (GeeAbstractSortedSet* self,
                                                       gconstpointer element);
static gpointer gee_abstract_sorted_set_real_lower (GeeAbstractSortedSet* self,
                                             gconstpointer element);
static gpointer gee_abstract_sorted_set_real_higher (GeeAbstractSortedSet* self,
                                              gconstpointer element);
static gpointer gee_abstract_sorted_set_real_floor (GeeAbstractSortedSet* self,
                                             gconstpointer element);
static gpointer gee_abstract_sorted_set_real_ceil (GeeAbstractSortedSet* self,
                                            gconstpointer element);
static GeeSortedSet* gee_abstract_sorted_set_real_head_set (GeeAbstractSortedSet* self,
                                                     gconstpointer before);
static GeeSortedSet* gee_abstract_sorted_set_real_tail_set (GeeAbstractSortedSet* self,
                                                     gconstpointer after);
static GeeSortedSet* gee_abstract_sorted_set_real_sub_set (GeeAbstractSortedSet* self,
                                                    gconstpointer from,
                                                    gconstpointer to);
static void gee_abstract_sorted_set_real_reserved0 (GeeAbstractSortedSet* self);
static void gee_abstract_sorted_set_real_reserved1 (GeeAbstractSortedSet* self);
static void gee_abstract_sorted_set_real_reserved2 (GeeAbstractSortedSet* self);
static void gee_abstract_sorted_set_real_reserved3 (GeeAbstractSortedSet* self);
static void gee_abstract_sorted_set_real_reserved4 (GeeAbstractSortedSet* self);
static void gee_abstract_sorted_set_real_reserved5 (GeeAbstractSortedSet* self);
static void gee_abstract_sorted_set_real_reserved6 (GeeAbstractSortedSet* self);
static void gee_abstract_sorted_set_real_reserved7 (GeeAbstractSortedSet* self);
static void gee_abstract_sorted_set_real_reserved8 (GeeAbstractSortedSet* self);
static void gee_abstract_sorted_set_real_reserved9 (GeeAbstractSortedSet* self);
 G_GNUC_INTERNAL GeeReadOnlySortedSet* gee_read_only_sorted_set_new (GType g_type,
                                                    GBoxedCopyFunc g_dup_func,
                                                    GDestroyNotify g_destroy_func,
                                                    GeeSortedSet* set);
 G_GNUC_INTERNAL GeeReadOnlySortedSet* gee_read_only_sorted_set_construct (GType object_type,
                                                          GType g_type,
                                                          GBoxedCopyFunc g_dup_func,
                                                          GDestroyNotify g_destroy_func,
                                                          GeeSortedSet* set);
 G_GNUC_INTERNAL GType gee_read_only_collection_get_type (void) G_GNUC_CONST  G_GNUC_UNUSED ;
 G_GNUC_INTERNAL GType gee_read_only_set_get_type (void) G_GNUC_CONST  G_GNUC_UNUSED ;
 G_GNUC_INTERNAL GType gee_read_only_sorted_set_get_type (void) G_GNUC_CONST  G_GNUC_UNUSED ;
static GObject * gee_abstract_sorted_set_constructor (GType type,
                                               guint n_construct_properties,
                                               GObjectConstructParam * construct_properties);
static void gee_abstract_sorted_set_finalize (GObject * obj);
static GType gee_abstract_sorted_set_get_type_once (void);
static void _vala_gee_abstract_sorted_set_get_property (GObject * object,
                                                 guint property_id,
                                                 GValue * value,
                                                 GParamSpec * pspec);
static void _vala_gee_abstract_sorted_set_set_property (GObject * object,
                                                 guint property_id,
                                                 const GValue * value,
                                                 GParamSpec * pspec);

static inline gpointer
gee_abstract_sorted_set_get_instance_private (GeeAbstractSortedSet* self)
{
	return G_STRUCT_MEMBER_P (self, GeeAbstractSortedSet_private_offset);
}

/**
 * {@inheritDoc}
 */
static gpointer
gee_abstract_sorted_set_real_first (GeeAbstractSortedSet* self)
{
	g_critical ("Type `%s' does not implement abstract method `gee_abstract_sorted_set_first'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
	return NULL;
}

gpointer
gee_abstract_sorted_set_first (GeeAbstractSortedSet* self)
{
	GeeAbstractSortedSetClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = GEE_ABSTRACT_SORTED_SET_GET_CLASS (self);
	if (_klass_->first) {
		return _klass_->first (self);
	}
	return NULL;
}

/**
 * {@inheritDoc}
 */
static gpointer
gee_abstract_sorted_set_real_last (GeeAbstractSortedSet* self)
{
	g_critical ("Type `%s' does not implement abstract method `gee_abstract_sorted_set_last'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
	return NULL;
}

gpointer
gee_abstract_sorted_set_last (GeeAbstractSortedSet* self)
{
	GeeAbstractSortedSetClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = GEE_ABSTRACT_SORTED_SET_GET_CLASS (self);
	if (_klass_->last) {
		return _klass_->last (self);
	}
	return NULL;
}

/**
 * {@inheritDoc}
 */
static GeeIterator*
gee_abstract_sorted_set_real_iterator_at (GeeAbstractSortedSet* self,
                                          gconstpointer element)
{
	g_critical ("Type `%s' does not implement abstract method `gee_abstract_sorted_set_iterator_at'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
	return NULL;
}

GeeIterator*
gee_abstract_sorted_set_iterator_at (GeeAbstractSortedSet* self,
                                     gconstpointer element)
{
	GeeAbstractSortedSetClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = GEE_ABSTRACT_SORTED_SET_GET_CLASS (self);
	if (_klass_->iterator_at) {
		return _klass_->iterator_at (self, element);
	}
	return NULL;
}

/**
 * {@inheritDoc}
 */
static gpointer
gee_abstract_sorted_set_real_lower (GeeAbstractSortedSet* self,
                                    gconstpointer element)
{
	g_critical ("Type `%s' does not implement abstract method `gee_abstract_sorted_set_lower'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
	return NULL;
}

gpointer
gee_abstract_sorted_set_lower (GeeAbstractSortedSet* self,
                               gconstpointer element)
{
	GeeAbstractSortedSetClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = GEE_ABSTRACT_SORTED_SET_GET_CLASS (self);
	if (_klass_->lower) {
		return _klass_->lower (self, element);
	}
	return NULL;
}

/**
 * {@inheritDoc}
 */
static gpointer
gee_abstract_sorted_set_real_higher (GeeAbstractSortedSet* self,
                                     gconstpointer element)
{
	g_critical ("Type `%s' does not implement abstract method `gee_abstract_sorted_set_higher'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
	return NULL;
}

gpointer
gee_abstract_sorted_set_higher (GeeAbstractSortedSet* self,
                                gconstpointer element)
{
	GeeAbstractSortedSetClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = GEE_ABSTRACT_SORTED_SET_GET_CLASS (self);
	if (_klass_->higher) {
		return _klass_->higher (self, element);
	}
	return NULL;
}

/**
 * {@inheritDoc}
 */
static gpointer
gee_abstract_sorted_set_real_floor (GeeAbstractSortedSet* self,
                                    gconstpointer element)
{
	g_critical ("Type `%s' does not implement abstract method `gee_abstract_sorted_set_floor'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
	return NULL;
}

gpointer
gee_abstract_sorted_set_floor (GeeAbstractSortedSet* self,
                               gconstpointer element)
{
	GeeAbstractSortedSetClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = GEE_ABSTRACT_SORTED_SET_GET_CLASS (self);
	if (_klass_->floor) {
		return _klass_->floor (self, element);
	}
	return NULL;
}

/**
 * {@inheritDoc}
 */
static gpointer
gee_abstract_sorted_set_real_ceil (GeeAbstractSortedSet* self,
                                   gconstpointer element)
{
	g_critical ("Type `%s' does not implement abstract method `gee_abstract_sorted_set_ceil'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
	return NULL;
}

gpointer
gee_abstract_sorted_set_ceil (GeeAbstractSortedSet* self,
                              gconstpointer element)
{
	GeeAbstractSortedSetClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = GEE_ABSTRACT_SORTED_SET_GET_CLASS (self);
	if (_klass_->ceil) {
		return _klass_->ceil (self, element);
	}
	return NULL;
}

/**
 * {@inheritDoc}
 */
static GeeSortedSet*
gee_abstract_sorted_set_real_head_set (GeeAbstractSortedSet* self,
                                       gconstpointer before)
{
	g_critical ("Type `%s' does not implement abstract method `gee_abstract_sorted_set_head_set'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
	return NULL;
}

GeeSortedSet*
gee_abstract_sorted_set_head_set (GeeAbstractSortedSet* self,
                                  gconstpointer before)
{
	GeeAbstractSortedSetClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = GEE_ABSTRACT_SORTED_SET_GET_CLASS (self);
	if (_klass_->head_set) {
		return _klass_->head_set (self, before);
	}
	return NULL;
}

/**
 * {@inheritDoc}
 */
static GeeSortedSet*
gee_abstract_sorted_set_real_tail_set (GeeAbstractSortedSet* self,
                                       gconstpointer after)
{
	g_critical ("Type `%s' does not implement abstract method `gee_abstract_sorted_set_tail_set'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
	return NULL;
}

GeeSortedSet*
gee_abstract_sorted_set_tail_set (GeeAbstractSortedSet* self,
                                  gconstpointer after)
{
	GeeAbstractSortedSetClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = GEE_ABSTRACT_SORTED_SET_GET_CLASS (self);
	if (_klass_->tail_set) {
		return _klass_->tail_set (self, after);
	}
	return NULL;
}

/**
 * {@inheritDoc}
 */
static GeeSortedSet*
gee_abstract_sorted_set_real_sub_set (GeeAbstractSortedSet* self,
                                      gconstpointer from,
                                      gconstpointer to)
{
	g_critical ("Type `%s' does not implement abstract method `gee_abstract_sorted_set_sub_set'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
	return NULL;
}

GeeSortedSet*
gee_abstract_sorted_set_sub_set (GeeAbstractSortedSet* self,
                                 gconstpointer from,
                                 gconstpointer to)
{
	GeeAbstractSortedSetClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = GEE_ABSTRACT_SORTED_SET_GET_CLASS (self);
	if (_klass_->sub_set) {
		return _klass_->sub_set (self, from, to);
	}
	return NULL;
}

static void
gee_abstract_sorted_set_real_reserved0 (GeeAbstractSortedSet* self)
{
}

void
gee_abstract_sorted_set_reserved0 (GeeAbstractSortedSet* self)
{
	GeeAbstractSortedSetClass* _klass_;
	g_return_if_fail (self != NULL);
	_klass_ = GEE_ABSTRACT_SORTED_SET_GET_CLASS (self);
	if (_klass_->reserved0) {
		_klass_->reserved0 (self);
	}
}

static void
gee_abstract_sorted_set_real_reserved1 (GeeAbstractSortedSet* self)
{
}

void
gee_abstract_sorted_set_reserved1 (GeeAbstractSortedSet* self)
{
	GeeAbstractSortedSetClass* _klass_;
	g_return_if_fail (self != NULL);
	_klass_ = GEE_ABSTRACT_SORTED_SET_GET_CLASS (self);
	if (_klass_->reserved1) {
		_klass_->reserved1 (self);
	}
}

static void
gee_abstract_sorted_set_real_reserved2 (GeeAbstractSortedSet* self)
{
}

void
gee_abstract_sorted_set_reserved2 (GeeAbstractSortedSet* self)
{
	GeeAbstractSortedSetClass* _klass_;
	g_return_if_fail (self != NULL);
	_klass_ = GEE_ABSTRACT_SORTED_SET_GET_CLASS (self);
	if (_klass_->reserved2) {
		_klass_->reserved2 (self);
	}
}

static void
gee_abstract_sorted_set_real_reserved3 (GeeAbstractSortedSet* self)
{
}

void
gee_abstract_sorted_set_reserved3 (GeeAbstractSortedSet* self)
{
	GeeAbstractSortedSetClass* _klass_;
	g_return_if_fail (self != NULL);
	_klass_ = GEE_ABSTRACT_SORTED_SET_GET_CLASS (self);
	if (_klass_->reserved3) {
		_klass_->reserved3 (self);
	}
}

static void
gee_abstract_sorted_set_real_reserved4 (GeeAbstractSortedSet* self)
{
}

void
gee_abstract_sorted_set_reserved4 (GeeAbstractSortedSet* self)
{
	GeeAbstractSortedSetClass* _klass_;
	g_return_if_fail (self != NULL);
	_klass_ = GEE_ABSTRACT_SORTED_SET_GET_CLASS (self);
	if (_klass_->reserved4) {
		_klass_->reserved4 (self);
	}
}

static void
gee_abstract_sorted_set_real_reserved5 (GeeAbstractSortedSet* self)
{
}

void
gee_abstract_sorted_set_reserved5 (GeeAbstractSortedSet* self)
{
	GeeAbstractSortedSetClass* _klass_;
	g_return_if_fail (self != NULL);
	_klass_ = GEE_ABSTRACT_SORTED_SET_GET_CLASS (self);
	if (_klass_->reserved5) {
		_klass_->reserved5 (self);
	}
}

static void
gee_abstract_sorted_set_real_reserved6 (GeeAbstractSortedSet* self)
{
}

void
gee_abstract_sorted_set_reserved6 (GeeAbstractSortedSet* self)
{
	GeeAbstractSortedSetClass* _klass_;
	g_return_if_fail (self != NULL);
	_klass_ = GEE_ABSTRACT_SORTED_SET_GET_CLASS (self);
	if (_klass_->reserved6) {
		_klass_->reserved6 (self);
	}
}

static void
gee_abstract_sorted_set_real_reserved7 (GeeAbstractSortedSet* self)
{
}

void
gee_abstract_sorted_set_reserved7 (GeeAbstractSortedSet* self)
{
	GeeAbstractSortedSetClass* _klass_;
	g_return_if_fail (self != NULL);
	_klass_ = GEE_ABSTRACT_SORTED_SET_GET_CLASS (self);
	if (_klass_->reserved7) {
		_klass_->reserved7 (self);
	}
}

static void
gee_abstract_sorted_set_real_reserved8 (GeeAbstractSortedSet* self)
{
}

void
gee_abstract_sorted_set_reserved8 (GeeAbstractSortedSet* self)
{
	GeeAbstractSortedSetClass* _klass_;
	g_return_if_fail (self != NULL);
	_klass_ = GEE_ABSTRACT_SORTED_SET_GET_CLASS (self);
	if (_klass_->reserved8) {
		_klass_->reserved8 (self);
	}
}

static void
gee_abstract_sorted_set_real_reserved9 (GeeAbstractSortedSet* self)
{
}

void
gee_abstract_sorted_set_reserved9 (GeeAbstractSortedSet* self)
{
	GeeAbstractSortedSetClass* _klass_;
	g_return_if_fail (self != NULL);
	_klass_ = GEE_ABSTRACT_SORTED_SET_GET_CLASS (self);
	if (_klass_->reserved9) {
		_klass_->reserved9 (self);
	}
}

GeeAbstractSortedSet*
gee_abstract_sorted_set_construct (GType object_type,
                                   GType g_type,
                                   GBoxedCopyFunc g_dup_func,
                                   GDestroyNotify g_destroy_func)
{
	GeeAbstractSortedSet * self = NULL;
	self = (GeeAbstractSortedSet*) gee_abstract_set_construct (object_type, g_type, (GBoxedCopyFunc) g_dup_func, (GDestroyNotify) g_destroy_func);
	self->priv->g_type = g_type;
	self->priv->g_dup_func = g_dup_func;
	self->priv->g_destroy_func = g_destroy_func;
	return self;
}

GeeSortedSet*
gee_abstract_sorted_set_get_read_only_view (GeeAbstractSortedSet* self)
{
	GeeAbstractSortedSetClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = GEE_ABSTRACT_SORTED_SET_GET_CLASS (self);
	if (_klass_->get_read_only_view) {
		return _klass_->get_read_only_view (self);
	}
	return NULL;
}

static GeeSortedSet*
gee_abstract_sorted_set_real_get_read_only_view (GeeAbstractSortedSet* base)
{
	GeeSortedSet* result;
	GeeAbstractSortedSet* self;
	GeeSortedSet* instance = NULL;
	GObject* _tmp0_;
	GeeSortedSet* _tmp1_;
	self = base;
	_tmp0_ = g_weak_ref_get (&self->priv->_read_only_view);
	instance = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_SORTED_SET, GeeSortedSet);
	_tmp1_ = instance;
	if (_tmp1_ == NULL) {
		GeeReadOnlySortedSet* _tmp2_;
		GeeSortedSet* _tmp3_;
		_tmp2_ = gee_read_only_sorted_set_new (self->priv->g_type, (GBoxedCopyFunc) self->priv->g_dup_func, (GDestroyNotify) self->priv->g_destroy_func, (GeeSortedSet*) self);
		_g_object_unref0 (instance);
		instance = (GeeSortedSet*) _tmp2_;
		_tmp3_ = instance;
		g_weak_ref_set (&self->priv->_read_only_view, (GObject*) _tmp3_);
	}
	result = instance;
	return result;
}

static GObject *
gee_abstract_sorted_set_constructor (GType type,
                                     guint n_construct_properties,
                                     GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GeeAbstractSortedSet * self;
	parent_class = G_OBJECT_CLASS (gee_abstract_sorted_set_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GEE_TYPE_ABSTRACT_SORTED_SET, GeeAbstractSortedSet);
	g_weak_ref_clear (&self->priv->_read_only_view);
	g_weak_ref_init (&self->priv->_read_only_view, NULL);
	return obj;
}

static void
gee_abstract_sorted_set_class_init (GeeAbstractSortedSetClass * klass,
                                    gpointer klass_data)
{
	gee_abstract_sorted_set_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &GeeAbstractSortedSet_private_offset);
	((GeeAbstractSortedSetClass *) klass)->first = (gpointer (*) (GeeAbstractSortedSet*)) gee_abstract_sorted_set_real_first;
	((GeeAbstractSortedSetClass *) klass)->last = (gpointer (*) (GeeAbstractSortedSet*)) gee_abstract_sorted_set_real_last;
	((GeeAbstractSortedSetClass *) klass)->iterator_at = (GeeIterator* (*) (GeeAbstractSortedSet*, gconstpointer)) gee_abstract_sorted_set_real_iterator_at;
	((GeeAbstractSortedSetClass *) klass)->lower = (gpointer (*) (GeeAbstractSortedSet*, gconstpointer)) gee_abstract_sorted_set_real_lower;
	((GeeAbstractSortedSetClass *) klass)->higher = (gpointer (*) (GeeAbstractSortedSet*, gconstpointer)) gee_abstract_sorted_set_real_higher;
	((GeeAbstractSortedSetClass *) klass)->floor = (gpointer (*) (GeeAbstractSortedSet*, gconstpointer)) gee_abstract_sorted_set_real_floor;
	((GeeAbstractSortedSetClass *) klass)->ceil = (gpointer (*) (GeeAbstractSortedSet*, gconstpointer)) gee_abstract_sorted_set_real_ceil;
	((GeeAbstractSortedSetClass *) klass)->head_set = (GeeSortedSet* (*) (GeeAbstractSortedSet*, gconstpointer)) gee_abstract_sorted_set_real_head_set;
	((GeeAbstractSortedSetClass *) klass)->tail_set = (GeeSortedSet* (*) (GeeAbstractSortedSet*, gconstpointer)) gee_abstract_sorted_set_real_tail_set;
	((GeeAbstractSortedSetClass *) klass)->sub_set = (GeeSortedSet* (*) (GeeAbstractSortedSet*, gconstpointer, gconstpointer)) gee_abstract_sorted_set_real_sub_set;
	((GeeAbstractSortedSetClass *) klass)->reserved0 = (void (*) (GeeAbstractSortedSet*)) gee_abstract_sorted_set_real_reserved0;
	((GeeAbstractSortedSetClass *) klass)->reserved1 = (void (*) (GeeAbstractSortedSet*)) gee_abstract_sorted_set_real_reserved1;
	((GeeAbstractSortedSetClass *) klass)->reserved2 = (void (*) (GeeAbstractSortedSet*)) gee_abstract_sorted_set_real_reserved2;
	((GeeAbstractSortedSetClass *) klass)->reserved3 = (void (*) (GeeAbstractSortedSet*)) gee_abstract_sorted_set_real_reserved3;
	((GeeAbstractSortedSetClass *) klass)->reserved4 = (void (*) (GeeAbstractSortedSet*)) gee_abstract_sorted_set_real_reserved4;
	((GeeAbstractSortedSetClass *) klass)->reserved5 = (void (*) (GeeAbstractSortedSet*)) gee_abstract_sorted_set_real_reserved5;
	((GeeAbstractSortedSetClass *) klass)->reserved6 = (void (*) (GeeAbstractSortedSet*)) gee_abstract_sorted_set_real_reserved6;
	((GeeAbstractSortedSetClass *) klass)->reserved7 = (void (*) (GeeAbstractSortedSet*)) gee_abstract_sorted_set_real_reserved7;
	((GeeAbstractSortedSetClass *) klass)->reserved8 = (void (*) (GeeAbstractSortedSet*)) gee_abstract_sorted_set_real_reserved8;
	((GeeAbstractSortedSetClass *) klass)->reserved9 = (void (*) (GeeAbstractSortedSet*)) gee_abstract_sorted_set_real_reserved9;
	GEE_ABSTRACT_SORTED_SET_CLASS (klass)->get_read_only_view = (GeeSortedSet* (*) (GeeAbstractSortedSet*)) gee_abstract_sorted_set_real_get_read_only_view;
	G_OBJECT_CLASS (klass)->get_property = _vala_gee_abstract_sorted_set_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_gee_abstract_sorted_set_set_property;
	G_OBJECT_CLASS (klass)->constructor = gee_abstract_sorted_set_constructor;
	G_OBJECT_CLASS (klass)->finalize = gee_abstract_sorted_set_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_ABSTRACT_SORTED_SET_G_TYPE, g_param_spec_gtype ("g-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_STRINGS | G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_ABSTRACT_SORTED_SET_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_STRINGS | G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_ABSTRACT_SORTED_SET_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_STRINGS | G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
	/**
	 * {@inheritDoc}
	 */
	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_ABSTRACT_SORTED_SET_READ_ONLY_VIEW_PROPERTY, gee_abstract_sorted_set_properties[GEE_ABSTRACT_SORTED_SET_READ_ONLY_VIEW_PROPERTY] = g_param_spec_object ("read-only-view", "read-only-view", "read-only-view", GEE_TYPE_SORTED_SET, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
}

static GType
gee_abstract_sorted_set_gee_sorted_set_get_g_type (GeeAbstractSortedSet* self)
{
	return (GType) self->priv->g_type;
}

static GBoxedCopyFunc
gee_abstract_sorted_set_gee_sorted_set_get_g_dup_func (GeeAbstractSortedSet* self)
{
	return (GBoxedCopyFunc) self->priv->g_dup_func;
}

static GDestroyNotify
gee_abstract_sorted_set_gee_sorted_set_get_g_destroy_func (GeeAbstractSortedSet* self)
{
	return (GDestroyNotify) self->priv->g_destroy_func;
}

static void
gee_abstract_sorted_set_gee_sorted_set_interface_init (GeeSortedSetIface * iface,
                                                       gpointer iface_data)
{
	gee_abstract_sorted_set_gee_sorted_set_parent_iface = g_type_interface_peek_parent (iface);
	iface->first = (gpointer (*) (GeeSortedSet*)) gee_abstract_sorted_set_first;
	iface->last = (gpointer (*) (GeeSortedSet*)) gee_abstract_sorted_set_last;
	iface->iterator_at = (GeeIterator* (*) (GeeSortedSet*, gconstpointer)) gee_abstract_sorted_set_iterator_at;
	iface->lower = (gpointer (*) (GeeSortedSet*, gconstpointer)) gee_abstract_sorted_set_lower;
	iface->higher = (gpointer (*) (GeeSortedSet*, gconstpointer)) gee_abstract_sorted_set_higher;
	iface->floor = (gpointer (*) (GeeSortedSet*, gconstpointer)) gee_abstract_sorted_set_floor;
	iface->ceil = (gpointer (*) (GeeSortedSet*, gconstpointer)) gee_abstract_sorted_set_ceil;
	iface->head_set = (GeeSortedSet* (*) (GeeSortedSet*, gconstpointer)) gee_abstract_sorted_set_head_set;
	iface->tail_set = (GeeSortedSet* (*) (GeeSortedSet*, gconstpointer)) gee_abstract_sorted_set_tail_set;
	iface->sub_set = (GeeSortedSet* (*) (GeeSortedSet*, gconstpointer, gconstpointer)) gee_abstract_sorted_set_sub_set;
	iface->get_g_type = (GType (*) (GeeSortedSet *)) gee_abstract_sorted_set_gee_sorted_set_get_g_type;
	iface->get_g_dup_func = (GBoxedCopyFunc (*) (GeeSortedSet *)) gee_abstract_sorted_set_gee_sorted_set_get_g_dup_func;
	iface->get_g_destroy_func = (GDestroyNotify (*) (GeeSortedSet *)) gee_abstract_sorted_set_gee_sorted_set_get_g_destroy_func;
	iface->get_read_only_view = (GeeSortedSet* (*) (GeeSortedSet*)) gee_abstract_sorted_set_get_read_only_view;
}

static void
gee_abstract_sorted_set_instance_init (GeeAbstractSortedSet * self,
                                       gpointer klass)
{
	self->priv = gee_abstract_sorted_set_get_instance_private (self);
}

static void
gee_abstract_sorted_set_finalize (GObject * obj)
{
	GeeAbstractSortedSet * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GEE_TYPE_ABSTRACT_SORTED_SET, GeeAbstractSortedSet);
	g_weak_ref_clear (&self->priv->_read_only_view);
	G_OBJECT_CLASS (gee_abstract_sorted_set_parent_class)->finalize (obj);
}

/**
 * Skeletal implementation of the {@link SortedSet} interface.
 *
 * Contains common code shared by all set implementations.
 *
 * @see TreeSet
 */
static GType
gee_abstract_sorted_set_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (GeeAbstractSortedSetClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_abstract_sorted_set_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeAbstractSortedSet), 0, (GInstanceInitFunc) gee_abstract_sorted_set_instance_init, NULL };
	static const GInterfaceInfo gee_sorted_set_info = { (GInterfaceInitFunc) gee_abstract_sorted_set_gee_sorted_set_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
	GType gee_abstract_sorted_set_type_id;
	gee_abstract_sorted_set_type_id = g_type_register_static (GEE_TYPE_ABSTRACT_SET, "GeeAbstractSortedSet", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
	g_type_add_interface_static (gee_abstract_sorted_set_type_id, GEE_TYPE_SORTED_SET, &gee_sorted_set_info);
	GeeAbstractSortedSet_private_offset = g_type_add_instance_private (gee_abstract_sorted_set_type_id, sizeof (GeeAbstractSortedSetPrivate));
	return gee_abstract_sorted_set_type_id;
}

GType
gee_abstract_sorted_set_get_type (void)
{
	static volatile gsize gee_abstract_sorted_set_type_id__once = 0;
	if (g_once_init_enter (&gee_abstract_sorted_set_type_id__once)) {
		GType gee_abstract_sorted_set_type_id;
		gee_abstract_sorted_set_type_id = gee_abstract_sorted_set_get_type_once ();
		g_once_init_leave (&gee_abstract_sorted_set_type_id__once, gee_abstract_sorted_set_type_id);
	}
	return gee_abstract_sorted_set_type_id__once;
}

static void
_vala_gee_abstract_sorted_set_get_property (GObject * object,
                                            guint property_id,
                                            GValue * value,
                                            GParamSpec * pspec)
{
	GeeAbstractSortedSet * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GEE_TYPE_ABSTRACT_SORTED_SET, GeeAbstractSortedSet);
	switch (property_id) {
		case GEE_ABSTRACT_SORTED_SET_READ_ONLY_VIEW_PROPERTY:
		g_value_take_object (value, gee_abstract_sorted_set_get_read_only_view (self));
		break;
		case GEE_ABSTRACT_SORTED_SET_G_TYPE:
		g_value_set_gtype (value, self->priv->g_type);
		break;
		case GEE_ABSTRACT_SORTED_SET_G_DUP_FUNC:
		g_value_set_pointer (value, self->priv->g_dup_func);
		break;
		case GEE_ABSTRACT_SORTED_SET_G_DESTROY_FUNC:
		g_value_set_pointer (value, self->priv->g_destroy_func);
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_gee_abstract_sorted_set_set_property (GObject * object,
                                            guint property_id,
                                            const GValue * value,
                                            GParamSpec * pspec)
{
	GeeAbstractSortedSet * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GEE_TYPE_ABSTRACT_SORTED_SET, GeeAbstractSortedSet);
	switch (property_id) {
		case GEE_ABSTRACT_SORTED_SET_G_TYPE:
		self->priv->g_type = g_value_get_gtype (value);
		break;
		case GEE_ABSTRACT_SORTED_SET_G_DUP_FUNC:
		self->priv->g_dup_func = g_value_get_pointer (value);
		break;
		case GEE_ABSTRACT_SORTED_SET_G_DESTROY_FUNC:
		self->priv->g_destroy_func = g_value_get_pointer (value);
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

